#!/usr/bin/env python

from journalism.columns import TextType, BooleanType, NumberType, DateType
from journalism.exceptions import *
from journalism.table import Table

def save():
    raise NotImplementedError
